# geoca 介绍

[![image](https://img.shields.io/pypi/v/geoca.svg)](https://pypi.python.org/pypi/geoca)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

**基于地理栅格数据的 CA 模型 Python 模块**

- 开源许可证：MIT License
- 文档网站：[https://Haorui-Jiang.github.io/geoca](https://Haorui-Jiang.github.io/geoca)

## 主要功能

- 从文件中读取栅格数据，并将数据转换成 Python 列表等格式。
- 根据输入的栅格数据创建栅格模板，并将数据统一替换到该栅格模板的对应位置。
- 根据栅格数据运行 CA 模型，分析人口或其他资源的迁移情况。
